==> attal_0.8.orig.tar.gz: attal-0.8/i18n/de/scenario_editor_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Rasse: </translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Art: </translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Anzahl: </translation>
    </message>
</context>
<context>
    <name>FillDialog</name>
    <message>
        <source>Choose tile</source>
        <translation>Wähle Kachel</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>PropertiesBase</name>
    <message>
        <source>Base properties</source>
        <translation>Basis-Konfiguration</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Besitzer: </translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Gebäude</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Niemand</translation>
    </message>
</context>
<context>
    <name>PropertiesCreature</name>
    <message>
        <source>Number of Creatures: </source>
        <translation type="obsolete">Anzahl an Truppen: </translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Behaviour of Creatures: </source>
        <translation>Verhalten der Kreaturen: </translation>
    </message>
    <message>
        <source>Never flee: </source>
        <translation>Niemals fliehen: </translation>
    </message>
    <message>
        <source>Looking at right side: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of creatures in stack %d: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>PropertiesLord</name>
    <message>
        <source>Lord properties</source>
        <translation>Fürst-Konfiguration</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Units</source>
        <translation>Einheiten</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Artefakte</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Kriegsmaschinerie</translation>
    </message>
    <message>
        <source>Technics</source>
        <translation>Sonderfähigkeiten</translation>
    </message>
    <message>
        <source>Lord&apos;s properties error</source>
        <translation>Fehler in der Fürst-Konfiguration</translation>
    </message>
    <message>
        <source>The lord must have at least 1 unit</source>
        <translation>Der Fürst muss mindestens eine Einheit haben</translation>
    </message>
</context>
<context>
    <name>PropertiesLordArtefacts</name>
    <message>
        <source>Common artefacts list</source>
        <translation>Alle Artefakte</translation>
    </message>
    <message>
        <source>Lord&apos;s artefacts list</source>
        <translation>Artefakte des Fürsten</translation>
    </message>
</context>
<context>
    <name>PropertiesLordGeneral</name>
    <message>
        <source>Select player:</source>
        <translation>Wähle Spieler: </translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standardwerte</translation>
    </message>
</context>
<context>
    <name>PropertiesLordTechnics</name>
    <message>
        <source>Common technics list</source>
        <translation>Alle Spezialfähigkeiten</translation>
    </message>
    <message>
        <source>Lord&apos;s technics list</source>
        <translation>Spezialfähigkeiten des Fürsten</translation>
    </message>
</context>
<context>
    <name>PropertiesLordWarMachines</name>
    <message>
        <source>Common war machines list</source>
        <translation>Alle Kriegsgeräte</translation>
    </message>
    <message>
        <source>Lord&apos;s war machines list</source>
        <translation>Kriegsgeräte des Fürsten</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tile</source>
        <translation>Kacheln</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation>Übergange</translation>
    </message>
    <message>
        <source>Decoration</source>
        <translation>Verzierungen</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Gebäude</translation>
    </message>
    <message>
        <source>Base</source>
        <translation>Basen</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Fürsten</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Artefakte</translation>
    </message>
    <message>
        <source>Creature</source>
        <translation>Kreaturen</translation>
    </message>
    <message>
        <source>Tool</source>
        <translation>Werkzeuge</translation>
    </message>
    <message>
        <source>Bonus</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScenarioInfo</name>
    <message>
        <source>General Scenario Informations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of players: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map height: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map width: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <source>Map </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map for Attal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScenarioInterface</name>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>Ö&amp;ffnen</translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <source>&amp;Save as</source>
        <translation>Speichern &amp;unter</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenario information</source>
        <translation>Szenario-Informationen</translation>
    </message>
    <message>
        <source>&amp;Scenario information</source>
        <translation>&amp;Szenario-Informationen</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Players properties</source>
        <translation>Spieler-Eigenschaften</translation>
    </message>
    <message>
        <source>&amp;Players properties</source>
        <translation>&amp;Spieler-Eigenschaften</translation>
    </message>
    <message>
        <source>CTRL+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear screen</source>
        <translation>Leere Karte</translation>
    </message>
    <message>
        <source>&amp;Clear screen</source>
        <translation>&amp;Leere Karte</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill screen</source>
        <translation>Fülle Karte</translation>
    </message>
    <message>
        <source>&amp;Fill screen</source>
        <translation>&amp;Fülle Karte</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Scenario</source>
        <translation>&amp;Szenario</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Werkzeuge</translation>
    </message>
</context>
<context>
    <name>TilePresentation</name>
    <message>
        <source>%d (weight=%d)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/de/scenario_editor_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AskLordCharac</name>
    <message>
        <source>Charac</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisplayQuests</name>
    <message>
        <source>Main quest: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other quests:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Rasse: </translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Art: </translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Anzahl: </translation>
    </message>
</context>
<context>
    <name>FillDialog</name>
    <message>
        <source>Choose tile</source>
        <translation>Wähle Kachel</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>%d (weight=%d)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewQuestConditionDialog</name>
    <message>
        <source>AND</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lord</source>
        <translation type="unfinished">Fürsten</translation>
    </message>
    <message>
        <source>Player</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesBase</name>
    <message>
        <source>Base properties</source>
        <translation>Basis-Konfiguration</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Besitzer: </translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Gebäude</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Niemand</translation>
    </message>
</context>
<context>
    <name>PropertiesBonus</name>
    <message>
        <source>Resource: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fixed value: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Primary skill: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defense</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Knowledge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add value: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bonus for secondary skills are not yet implemented</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bonus for spells are not yet implemented</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesBuilding</name>
    <message>
        <source>building properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation type="unfinished">Besitzer: </translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished">Niemand</translation>
    </message>
</context>
<context>
    <name>PropertiesCreature</name>
    <message>
        <source>Number of Creatures: </source>
        <translation type="obsolete">Anzahl an Truppen: </translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Behaviour of Creatures: </source>
        <translation>Verhalten der Kreaturen: </translation>
    </message>
    <message>
        <source>Never flee: </source>
        <translation>Niemals fliehen: </translation>
    </message>
    <message>
        <source>Looking at right side: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of creatures in stack %d: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>PropertiesEvent</name>
    <message>
        <source>Condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
</context>
<context>
    <name>PropertiesLord</name>
    <message>
        <source>Lord properties</source>
        <translation>Fürst-Konfiguration</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Units</source>
        <translation>Einheiten</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Artefakte</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Kriegsmaschinerie</translation>
    </message>
    <message>
        <source>Technics</source>
        <translation>Sonderfähigkeiten</translation>
    </message>
    <message>
        <source>Lord&apos;s properties error</source>
        <translation>Fehler in der Fürst-Konfiguration</translation>
    </message>
    <message>
        <source>The lord must have at least 1 unit</source>
        <translation>Der Fürst muss mindestens eine Einheit haben</translation>
    </message>
</context>
<context>
    <name>PropertiesLordArtefacts</name>
    <message>
        <source>Common artefacts list</source>
        <translation>Alle Artefakte</translation>
    </message>
    <message>
        <source>Lord&apos;s artefacts list</source>
        <translation>Artefakte des Fürsten</translation>
    </message>
</context>
<context>
    <name>PropertiesLordGeneral</name>
    <message>
        <source>Select player:</source>
        <translation>Wähle Spieler: </translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standardwerte</translation>
    </message>
</context>
<context>
    <name>PropertiesLordTechnics</name>
    <message>
        <source>Common technics list</source>
        <translation>Alle Spezialfähigkeiten</translation>
    </message>
    <message>
        <source>Lord&apos;s technics list</source>
        <translation>Spezialfähigkeiten des Fürsten</translation>
    </message>
</context>
<context>
    <name>PropertiesLordWarMachines</name>
    <message>
        <source>Common war machines list</source>
        <translation>Alle Kriegsgeräte</translation>
    </message>
    <message>
        <source>Lord&apos;s war machines list</source>
        <translation>Kriegsgeräte des Fürsten</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tile</source>
        <translation>Kacheln</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation>Übergange</translation>
    </message>
    <message>
        <source>Decoration</source>
        <translation>Verzierungen</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Gebäude</translation>
    </message>
    <message>
        <source>Base</source>
        <translation>Basen</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Fürsten</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Artefakte</translation>
    </message>
    <message>
        <source>Creature</source>
        <translation>Kreaturen</translation>
    </message>
    <message>
        <source>Tool</source>
        <translation>Werkzeuge</translation>
    </message>
    <message>
        <source>Bonus</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuestConditionDateProperties</name>
    <message>
        <source>Before date: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Before </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>day(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>QuestConditionDialog</name>
    <message>
        <source>Condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete condition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuestConditionEditor</name>
    <message>
        <source>Condition: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuestConditionLordProperties</name>
    <message>
        <source>Primary skill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>value: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Secondary skill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation type="unfinished">Artefakte</translation>
    </message>
    <message>
        <source>Spell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>QuestEditor</name>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ask player confirmation of quest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirmation question: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <source>Start condition: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fail condition: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Success condition: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScenarioInfo</name>
    <message>
        <source>General Scenario Informations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of players: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map height: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map width: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <source>Map </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map for Attal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScenarioInterface</name>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>Ö&amp;ffnen</translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <source>&amp;Save as</source>
        <translation>Speichern &amp;unter</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenario information</source>
        <translation>Szenario-Informationen</translation>
    </message>
    <message>
        <source>&amp;Scenario information</source>
        <translation>&amp;Szenario-Informationen</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Players properties</source>
        <translation>Spieler-Eigenschaften</translation>
    </message>
    <message>
        <source>&amp;Players properties</source>
        <translation>&amp;Spieler-Eigenschaften</translation>
    </message>
    <message>
        <source>CTRL+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear screen</source>
        <translation>Leere Karte</translation>
    </message>
    <message>
        <source>&amp;Clear screen</source>
        <translation>&amp;Leere Karte</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill screen</source>
        <translation>Fülle Karte</translation>
    </message>
    <message>
        <source>&amp;Fill screen</source>
        <translation>&amp;Fülle Karte</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Scenario</source>
        <translation>&amp;Szenario</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Werkzeuge</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quests management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Screen</name>
    <message>
        <source>(Cell %dx%d)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TilePresentation</name>
    <message>
        <source>%d (weight=%d)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
